@@ -3,28 +3,26 @@
 # daemon/_metadata.py
 # Part of ‘python-daemon’, an implementation of PEP 3143.
 #
-# Copyright © 2008–2016 Ben Finney <ben+python@benfinney.id.au>
-#
-# This is free software: you may copy, modify, and/or distribute this work
-# under the terms of the Apache License, version 2.0 as published by the
-# Apache Software Foundation.
-# No warranty expressed or implied. See the file ‘LICENSE.ASF-2’ for details.
+# This is free software, and you are welcome to redistribute it under
+# certain conditions; see the end of this file for copyright
+# information, grant of license, and disclaimer of warranty.
 
 """ Package metadata for the ‘python-daemon’ distribution. """
 
 from __future__ import (absolute_import, unicode_literals)
 
-import json
-import re
-import collections
 import datetime
+import json
 
 import pkg_resources
 
+__metaclass__ = type
+
 
 distribution_name = "python-daemon"
 version_info_filename = "version_info.json"
 
+
 def get_distribution_version_info(filename=version_info_filename):
     """ Get the version info from the installed distribution.
 
@@ -48,45 +46,18 @@ def get_distribution_version_info(filename=version_info_filename):
         distribution = None
 
     if distribution is not None:
-        if distribution.has_metadata(version_info_filename):
-            content = distribution.get_metadata(version_info_filename)
+        if distribution.has_metadata(filename):
+            content = distribution.get_metadata(filename)
             version_info = json.loads(content)
 
     return version_info
 
+
 version_info = get_distribution_version_info()
 
 version_installed = version_info['version']
 
 
-rfc822_person_regex = re.compile(
-        "^(?P<name>[^<]+) <(?P<email>[^>]+)>$")
-
-ParsedPerson = collections.namedtuple('ParsedPerson', ['name', 'email'])
-
-def parse_person_field(value):
-    """ Parse a person field into name and email address.
-
-        :param value: The text value specifying a person.
-        :return: A 2-tuple (name, email) for the person's details.
-
-        If the `value` does not match a standard person with email
-        address, the `email` item is ``None``.
-
-        """
-    result = (None, None)
-
-    match = rfc822_person_regex.match(value)
-    if len(value):
-        if match is not None:
-            result = ParsedPerson(
-                    name=match.group('name'),
-                    email=match.group('email'))
-        else:
-            result = ParsedPerson(name=value, email=None)
-
-    return result    
-
 author_name = "Ben Finney"
 author_email = "ben+python@benfinney.id.au"
 author = "{name} <{email}>".format(name=author_name, email=author_email)
@@ -112,7 +83,8 @@ class YearRange:
 def make_year_range(begin_year, end_date=None):
     """ Construct the year range given a start and possible end date.
 
-        :param begin_date: The beginning year (text) for the range.
+        :param begin_year: The beginning year (text, 4 digits) for the
+            range.
         :param end_date: The end date (text, ISO-8601 format) for the
             range, or a non-date token string.
         :return: The range of years as a `YearRange` instance.
@@ -135,6 +107,7 @@ def make_year_range(begin_year, end_date=None):
 
     return year_range
 
+
 copyright_year_begin = "2001"
 build_date = version_info['release_date']
 copyright_year_range = make_year_range(copyright_year_begin, build_date)
@@ -142,7 +115,15 @@ copyright_year_range = make_year_range(copyright_year_begin, build_date)
 copyright = "Copyright © {year_range} {author} and others".format(
         year_range=copyright_year_range, author=author)
 license = "Apache-2"
-url = "https://alioth.debian.org/projects/python-daemon/"
+url = "https://pagure.io/python-daemon/"
+
+
+# Copyright © 2008–2019 Ben Finney <ben+python@benfinney.id.au>
+#
+# This is free software: you may copy, modify, and/or distribute this work
+# under the terms of the Apache License, version 2.0 as published by the
+# Apache Software Foundation.
+# No warranty expressed or implied. See the file ‘LICENSE.ASF-2’ for details.
 
 
 # Local variables:
