@@ -18,7 +18,6 @@ import functools
 import io
 import os
 import pwd
-import random
 import resource
 import signal
 import socket
@@ -1441,6 +1440,19 @@ def fake_get_maximum_file_descriptors():
     return fake_default_maxfd
 
 
+def make_get_maximum_file_descriptors_patch(self, fake_maxfd):
+    """ Make a `get_maximum_file_descriptors` patch for the `testcase`.
+
+        :param testcase: The `unittest.TestCase` instance to patch.
+        :param fake_maxfd: The fake maximum file descriptor value.
+        :return: The `unittest.mock.patch` object.
+        """
+    func_patcher = mock.patch.object(
+        daemon.daemon, "get_maximum_file_descriptors",
+        return_value=fake_maxfd)
+    return func_patcher
+
+
 class _get_candidate_file_descriptors_TestCase(scaffold.TestCaseWithScenarios):
     """ Test cases for function `_get_candidate_file_descriptors`. """
 
@@ -1470,9 +1482,7 @@ class _get_candidate_file_descriptors_TestCase(scaffold.TestCaseWithScenarios):
 
     def test_returns_expected_file_descriptors(self):
         """ Should return the expected set of file descriptors. """
-        with mock.patch.object(
-                daemon.daemon, "get_maximum_file_descriptors",
-                return_value=self.fake_maxfd):
+        with make_get_maximum_file_descriptors_patch(self, self.fake_maxfd):
             result = daemon.daemon._get_candidate_file_descriptors(
                     **self.test_kwargs)
         self.assertEqual(result, self.expected_result)
@@ -1483,7 +1493,21 @@ class _get_candidate_file_descriptor_ranges_TestCase(
     """ Test cases for function `_get_candidate_file_descriptor_ranges`. """
 
     scenarios = [
-            ('exclude-three', {
+            ('exclude-none', {
+                'fake_maxfd': 5,
+                'test_kwargs': {
+                    'exclude': set(),
+                },
+                'expected_result': [(0, 5)],
+                }),
+            ('exclude-all', {
+                'fake_maxfd': 5,
+                'test_kwargs': {
+                    'exclude': {0, 1, 2, 3, 4},
+                },
+                'expected_result': [],
+                }),
+            ('exclude-three-discrete', {
                 'fake_maxfd': 10,
                 'test_kwargs': {
                     'exclude': {3, 5, 8},
@@ -1495,6 +1519,35 @@ class _get_candidate_file_descriptor_ranges_TestCase(
                     (9, 10),
                     ],
                 }),
+            ('exclude-three-consecutive', {
+                'fake_maxfd': 10,
+                'test_kwargs': {
+                    'exclude': {3, 4, 5},
+                    },
+                'expected_result': [
+                    (0, 3),
+                    (6, 10),
+                    ],
+                }),
+            ('exclude-lowest', {
+                'fake_maxfd': 5,
+                'test_kwargs': {
+                    'exclude': {0},
+                    },
+                'expected_result': [
+                    (1, 5),
+                    ],
+                }),
+            ('exclude-middle', {
+                'fake_maxfd': 5,
+                'test_kwargs': {
+                    'exclude': {1, 2, 3},
+                    },
+                'expected_result': [
+                    (0, 1),
+                    (4, 5),
+                    ],
+                }),
             ('exclude-highest', {
                 'fake_maxfd': 5,
                 'test_kwargs': {
@@ -1504,20 +1557,29 @@ class _get_candidate_file_descriptor_ranges_TestCase(
                     (0, 4),
                     ],
                 }),
-            ('exclude-none', {
+            ('exclude-maxfd', {
                 'fake_maxfd': 5,
                 'test_kwargs': {
-                    'exclude': set(),
-                },
-                'expected_result': [(0, 5)],
+                    'exclude': {5},
+                    },
+                'expected_result': [
+                    (0, 5),
+                    ],
+                }),
+            ('exclude-out-of-bounds', {
+                'fake_maxfd': 5,
+                'test_kwargs': {
+                    'exclude': {-9, -3, 6, 10},
+                    },
+                'expected_result': [
+                    (0, 5),
+                    ],
                 }),
             ]
 
     def test_returns_expected_file_descriptors(self):
         """ Should return the expected set of file descriptors. """
-        with mock.patch.object(
-                daemon.daemon, "get_maximum_file_descriptors",
-                return_value=self.fake_maxfd):
+        with make_get_maximum_file_descriptors_patch(self, self.fake_maxfd):
             result = daemon.daemon._get_candidate_file_descriptor_ranges(
                     **self.test_kwargs)
         self.assertEqual(result, self.expected_result)
@@ -1531,7 +1593,7 @@ class _close_file_descriptor_ranges_TestCase(scaffold.TestCaseWithScenarios):
             ('ranges-one', {
                 'test_kwargs': {
                     'ranges': [
-                        daemon.daemon.FileDescriptorRange(0, 10),
+                        (0, 10),
                         ],
                     },
                 'expected_os_closerange_calls': [
@@ -1541,9 +1603,9 @@ class _close_file_descriptor_ranges_TestCase(scaffold.TestCaseWithScenarios):
             ('ranges-three', {
                 'test_kwargs': {
                     'ranges': [
-                        daemon.daemon.FileDescriptorRange(5, 10),
-                        daemon.daemon.FileDescriptorRange(0, 3),
-                        daemon.daemon.FileDescriptorRange(15, 20),
+                        (5, 10),
+                        (0, 3),
+                        (15, 20),
                         ],
                     },
                 'expected_os_closerange_calls': [
@@ -1571,16 +1633,13 @@ class close_all_open_files_TestCase(scaffold.TestCase):
         """ Set up test fixtures. """
         super(close_all_open_files_TestCase, self).setUp()
 
-        self.patch_get_maximum_file_descriptors(self.fake_maxfd)
-        self.patch_os_closerange()
+        get_maximum_file_descriptors_patch = (
+                make_get_maximum_file_descriptors_patch(
+                    self, fake_maxfd=self.fake_maxfd))
+        get_maximum_file_descriptors_patch.start()
+        self.addCleanup(get_maximum_file_descriptors_patch.stop)
 
-    def patch_get_maximum_file_descriptors(self, fake_maxfd):
-        """ Patch `get_maximum_file_descriptors` for this test case. """
-        func_patcher = mock.patch.object(
-            daemon.daemon, "get_maximum_file_descriptors",
-            return_value=fake_maxfd)
-        self.mock_func_get_maximum_file_descriptors = func_patcher.start()
-        self.addCleanup(func_patcher.stop)
+        self.patch_os_closerange()
 
     def patch_os_closerange(self):
         """ Patch `os.closerange` function for this test case. """
