@@ -137,6 +137,7 @@ class YearRange_TestCase(scaffold.TestCaseWithScenarios):
 
 FakeYearRange = collections.namedtuple('FakeYearRange', ['begin', 'end'])
 
+
 @mock.patch.object(metadata, 'YearRange', new=FakeYearRange)
 class make_year_range_TestCase(scaffold.TestCaseWithScenarios):
     """ Test cases for ‘make_year_range’ function. """
@@ -181,9 +182,9 @@ class metadata_content_TestCase(scaffold.TestCase):
     def test_copyright_formatted_correctly(self):
         """ Copyright statement should be formatted correctly. """
         regex_pattern = (
-                "Copyright © "
-                "\d{4}"  # Four-digit year.
-                "(?:–\d{4})?"  # Optional range dash and four-digit year.
+                r"Copyright © "
+                r"\d{4}"  # Four-digit year.
+                r"(?:–\d{4})?"  # Optional range dash and four-digit year.
                 )
         regex_flags = re.UNICODE
         self.assertThat(
@@ -193,8 +194,8 @@ class metadata_content_TestCase(scaffold.TestCase):
     def test_author_formatted_correctly(self):
         """ Author information should be formatted correctly. """
         regex_pattern = (
-                ".+ "  # Name.
-                "<[^>]+>"  # Email address, in angle brackets.
+                r".+ "  # Name.
+                r"<[^>]+>"  # Email address, in angle brackets.
                 )
         regex_flags = re.UNICODE
         self.assertThat(
@@ -224,6 +225,7 @@ except NameError:
 
 version_info_filename = "version_info.json"
 
+
 def fake_func_has_metadata(testcase, resource_name):
     """ Fake the behaviour of ‘pkg_resources.Distribution.has_metadata’. """
     if (
