@@ -298,21 +298,26 @@ def make_lockfile_method_fakes(scenario):
 
     def fake_func_read_pid():
         return scenario['pidfile_pid']
+
     def fake_func_is_locked():
         return (scenario['locking_pid'] is not None)
+
     def fake_func_i_am_locking():
         return (
                 scenario['locking_pid'] == scenario['pid'])
+
     def fake_func_acquire(timeout=None):
         if scenario['locking_pid'] is not None:
             raise lockfile.AlreadyLocked()
         scenario['locking_pid'] = scenario['pid']
+
     def fake_func_release():
         if scenario['locking_pid'] is None:
             raise lockfile.NotLocked()
         if scenario['locking_pid'] != scenario['pid']:
             raise lockfile.NotMyLock()
         scenario['locking_pid'] = None
+
     def fake_func_break_lock():
         scenario['locking_pid'] = None
 
@@ -321,7 +326,7 @@ def make_lockfile_method_fakes(scenario):
                 func_name.replace('fake_func_', ''),
                 mock.MagicMock(side_effect=fake_func))
             for (func_name, fake_func) in vars().items()
-                if func_name.startswith('fake_func_'))
+            if func_name.startswith('fake_func_'))
 
     return fake_methods
 
@@ -341,8 +346,8 @@ def apply_lockfile_method_mocks(mock_lockfile, testcase, scenario):
         """
     fake_methods = dict(
             (func_name, fake_func)
-            for (func_name, fake_func) in
-                make_lockfile_method_fakes(scenario).items()
+            for (func_name, fake_func) in (
+                make_lockfile_method_fakes(scenario).items())
             if func_name not in ['read_pid'])
 
     for (func_name, fake_func) in fake_methods.items():
